crikit.io.tests package — CRIKit2 0.4.3 documentation

# crikit.io.tests package

## Submodules

## crikit.io.tests.test_hdf5 module

crikit.io.tests.test_hdf5.hdf_dataset()

  Setups and tears down a sample HDF5 file

crikit.io.tests.test_hdf5.test_hdf_import_hsi_to_hsi(hdf_dataset)

  Import an hsi into an hsi

crikit.io.tests.test_hdf5.test_hdf_import_no_output_cls_given(hdf_dataset)

  Import a spectrum, spectra, and hsi when no instantiated class is provided

crikit.io.tests.test_hdf5.test_hdf_import_spectra_to_spectra(hdf_dataset)

  Import a spectra into a spectra

crikit.io.tests.test_hdf5.test_hdf_import_spectrum_to_spectrum(hdf_dataset)

  Import a spectrum into a spectrum

## Module contents